@@ -61,16 +61,15 @@
 #' @export
 #'
 #' @examples
-#' \dontrun{
+#' if (interactive()) {
+#'   hgd() # Initialize graphics device and start server
+#'   hgd_browse() # Or copy the displayed link in the browser
 #'
-#' hgd() # Initialize graphics device and start server
-#' hgd_browse() # Or copy the displayed link in the browser
+#'   # Plot something
+#'   x <- seq(0, 3 * pi, by = 0.1)
+#'   plot(x, sin(x), type = "l")
 #'
-#' # Plot something
-#' x <- seq(0, 3 * pi, by = 0.1)
-#' plot(x, sin(x), type = "l")
-#'
-#' dev.off() # alternatively: hgd_close()
+#'   dev.off() # alternatively: hgd_close()
 #' }
 hgd <-
   function(host = getOption("httpgd.host", "127.0.0.1"),
@@ -138,15 +137,13 @@ hgd <-
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' hgd_state()
 #' plot(1, 1)
 #' hgd_state()
 #'
 #' dev.off()
-#' }
 hgd_state <- function(which = dev.cur()) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
@@ -170,13 +167,11 @@ hgd_state <- function(which = dev.cur()) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' hgd_info()
 #'
 #' dev.off()
-#' }
 hgd_info <- function(which = dev.cur()) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
@@ -204,13 +199,11 @@ hgd_info <- function(which = dev.cur()) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' hgd_renderers()
 #'
 #' dev.off()
-#' }
 hgd_renderers <- function(which = dev.cur()) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
@@ -234,29 +227,25 @@ hgd_renderers <- function(which = dev.cur()) {
 #' @param state Include the current device state in the returned result
 #'  (see also: [hgd_state()]).
 #'
-#' @return TODO
+#' @return a list contains plot IDs.
 #'
 #' @importFrom grDevices dev.cur
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' plot.new()
 #' text(.5, .5, "#1")
 #' plot.new()
 #' text(.5, .5, "#2")
 #' plot.new()
 #' text(.5, .5, "#3")
-#' third <- hgd_id()
-#' second <- hgd_id(2)
-#' all <- hgd_id(1, limit = Inf)
-#' hgd_remove(1)
-#' hgd_svg(second)
+#' hgd_id() # The last one
+#' hgd_id(2) # The second one
+#' hgd_id(1, limit = Inf) # The first one and all the followings
 #'
 #' dev.off()
-#' }
 hgd_id <- function(index = 0, limit = 1, which = dev.cur(), state = FALSE) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
@@ -296,16 +285,17 @@ hgd_id <- function(index = 0, limit = 1, which = dev.cur(), state = FALSE) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' plot(1, 1)
 #' s <- hgd_svg(width = 600, height = 400)
+#'
 #' hist(rnorm(100))
-#' hgd_svg(file = tempfile(), width = 600, height = 400)
+#' tf <- tempfile()
+#' on.exit(unlink(tf))
+#' hgd_svg(file = tf, width = 600, height = 400)
 #'
 #' dev.off()
-#' }
 hgd_svg <-
   function(page = 0,
            width = -1,
@@ -347,16 +337,17 @@ hgd_svg <-
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' plot(1, 1)
-#' s <- hgd_svg(width = 600, height = 400)
+#' s <- hgd_plot(width = 600, height = 400)
+#'
 #' hist(rnorm(100))
-#' hgd_svg(file = tempfile(), width = 600, height = 400)
+#' tf <- tempfile()
+#' on.exit(unlink(tf))
+#' hgd_plot(file = tf, width = 600, height = 400)
 #'
 #' dev.off()
-#' }
 hgd_plot <- function(page = 0,
                      width = -1,
                      height = -1,
@@ -367,7 +358,7 @@ hgd_plot <- function(page = 0,
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
   }
-  if (class(page) == "httpgd_pid") {
+  if (inherits(page, "httpgd_pid")) {
     page <- httpgd_plot_find_(which, page$id)
   }
   if (httpgd_renderer_is_str_(renderer)) {
@@ -403,20 +394,18 @@ hgd_plot <- function(page = 0,
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' plot(1, 1) # page 1
 #' hist(rnorm(100)) # page 2
 #' hgd_remove(page = 1) # remove page 1
 #'
 #' dev.off()
-#' }
 hgd_remove <- function(page = 0, which = dev.cur()) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
   } else {
-    if (class(page) == "httpgd_pid") {
+    if (inherits(page, "httpgd_pid")) {
       return(httpgd_remove_id_(which, page$id))
     }
     return(httpgd_remove_(which, page - 1))
@@ -435,16 +424,13 @@ hgd_remove <- function(page = 0, which = dev.cur()) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
+#'
 #' plot(1, 1)
-#' hist(rnorm(100))
 #' hgd_clear()
-#' hist(rnorm(100))
+#' hgd_clear()
 #'
 #' dev.off()
-#' }
 hgd_clear <- function(which = dev.cur()) {
   if (names(which) != "httpgd") {
     stop("Device is not of type httpgd. (Start a device by calling: `hgd()`)")
@@ -486,15 +472,13 @@ build_http_query <- function(x) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
-#' my_url <- hgd_url()
+#'
+#' plot(1, 1)
 #' hgd_url(0)
-#' hgd_url(plot_id(), width = 800, height = 600)
+#' hgd_url(hgd_id(), width = 800, height = 600)
 #'
 #' dev.off()
-#' }
 hgd_url <- function(endpoint = "live",
                     which = dev.cur(),
                     websockets = TRUE,
@@ -507,7 +491,7 @@ hgd_url <- function(endpoint = "live",
                     explicit = FALSE) {
   l <- hgd_state(which)
   q <- list()
-  if (is.numeric(endpoint) || (class(endpoint) == "httpgd_pid")) {
+  if (is.numeric(endpoint) || inherits(endpoint, "httpgd_pid")) {
     if (is.numeric(endpoint)) {
       if (endpoint > 0) {
         q["index"] <- endpoint - 1
@@ -575,15 +559,7 @@ hgd_url <- function(endpoint = "live",
 #' @importFrom utils browseURL
 #' @export
 #'
-#' @examples
-#' \dontrun{
-#'
-#' hgd()
-#' hgd_browse() # open browser
-#' hist(rnorm(100))
-#'
-#' dev.off()
-#' }
+#' @inherit hgd examples
 hgd_browse <- function(..., which = dev.cur(), browser = getOption("browser")) {
   browseURL(url = hgd_url(..., which = which), browser = browser)
 }
@@ -600,13 +576,13 @@ hgd_browse <- function(..., which = dev.cur(), browser = getOption("browser")) {
 #' @export
 #'
 #' @examples
-#' \dontrun{
+#' if (interactive() && !is.null(getOption("viewer"))) {
+#'   hgd()
 #'
-#' hgd()
-#' hgd_view()
-#' hist(rnorm(100))
+#'   hgd_view()
+#'   hist(rnorm(100))
 #'
-#' dev.off()
+#'   dev.off()
 #' }
 hgd_view <- function() {
   v <- getOption("viewer")
@@ -634,10 +610,7 @@ hgd_view <- function() {
 #' @export
 #'
 #' @examples
-#' \dontrun{
-#'
 #' hgd()
-#' hgd_browse() # open browser
 #' hist(rnorm(100))
 #' hgd_close() # Equvalent to dev.off()
 #'
@@ -645,7 +618,6 @@ hgd_view <- function() {
 #' hgd()
 #' hgd()
 #' hgd_close(all = TRUE)
-#' }
 hgd_close <- function(which = dev.cur(), all = FALSE) {
   if (all) {
     ds <- dev.list()
