@@ -834,7 +834,7 @@ public:
   // serialize path and query parameters to the target
   void params_serialize()
   {
-    std::string path {target().to_string()};
+    std::string path {target().data(), target().size()};
 
     _path.clear();
     _path.emplace_back(path);
@@ -856,7 +856,7 @@ public:
   // parse the query parameters from the target
   void params_parse()
   {
-    std::string path {target().to_string()};
+    std::string path {target().data(), target().size()};
 
     // separate the query params
     auto params = Detail::split(path, "?", 1);
@@ -1610,7 +1610,7 @@ private:
         return 404;
       }
 
-      std::string path {_attr->public_dir + _ctx.req.target().to_string()};
+      std::string path {_attr->public_dir + std::string(_ctx.req.target().data(), _ctx.req.target().size())};
 
       if (path.back() == '/')
       {
@@ -1667,7 +1667,7 @@ private:
       std::regex_constants::match_flag_type const rx_flgs {std::regex_constants::match_not_null};
 
       // the request path
-      std::string path {_ctx.req.target().to_string()};
+      std::string path {_ctx.req.target().data(),_ctx.req.target().size()};
 
       // separate the query parameters
       auto params = Detail::split(path, "?", 1);
@@ -1759,7 +1759,7 @@ private:
       std::regex_constants::match_flag_type const rx_flgs {std::regex_constants::match_not_null};
 
       // the request path
-      std::string path {_ctx.req.target().to_string()};
+      std::string path {_ctx.req.target().data(), _ctx.req.target().size()};
 
       // separate the query parameters
       auto params = Detail::split(path, "?", 1);
@@ -1945,7 +1945,7 @@ private:
     bool handle_websocket()
     {
       // the request path
-      std::string path {_ctx.req.target().to_string()};
+      std::string path {_ctx.req.target().data(), _ctx.req.target().size()};
 
       // separate the query parameters
       auto params = Detail::split(path, "?", 1);
